@@ -30,20 +30,17 @@ class ActWrap(ActorBase):
         return self._f(task_arg)
 
 
-def get_simp_scheduler(n, fun, dist_sys, verbose, max_runs) -> Scheduler:
-    # TODO this will not work
-    ActWrap.restart_after = max_runs
-
+def get_simp_scheduler(n, Actor, dist_sys, verbose) -> Scheduler:
     return Scheduler(
-        actor_dict={CapabilitySet([_CAP]): partial(ActWrap, fun=fun)},
+        actor_dict={CapabilitySet([_CAP]): Actor},
         resource_limits={_RES: n},
         distributed_system=dist_sys,
         verbose=verbose,
     )
 
 
-def parallel_map(
-    fun,
+def parallel_consume(
+    Actor: type[ActorBase],
     iterable,
     dist_api=DEFAULT_MULTI_API,
     batch_size=None,
@@ -52,17 +49,19 @@ def parallel_map(
     raise_errors=True,
     verbose=False,
     pbar=False,
-    restart_after=float("inf"),
+    allowed_fail_count=0,
 ):
     nw = workers or cpu_count()
     batch_size = batch_size or nw * 5
     min_queue_size = min_queue_size or batch_size // 2
 
-    pinger = get_pinger(iterable) if pbar else lambda: None
-    scheduler = get_simp_scheduler(nw, fun, dist_api, verbose, restart_after)
+    pinger = get_pinger(iterable, pbar)
+    scheduler = get_simp_scheduler(nw, Actor, dist_api, verbose)
 
     out_iter = scheduler.process(
-        batch_producer=BatchProd(iterable, batch_size),
+        batch_producer=BatchProd(
+            iterable, batch_size, partial(_Task, allowed_fail_count=allowed_fail_count)
+        ),
         min_queue_size=min_queue_size,
     )
     try:
@@ -75,12 +74,40 @@ def parallel_map(
         scheduler.join()
 
 
-def get_pinger(iterable):
+def parallel_map(
+    fun,
+    iterable,
+    dist_api=DEFAULT_MULTI_API,
+    batch_size=None,
+    min_queue_size=None,
+    workers=None,
+    raise_errors=True,
+    verbose=False,
+    pbar=False,
+    allowed_fail_count=0,
+):
+    return parallel_consume(
+        partial(ActWrap, fun=fun),
+        iterable,
+        dist_api,
+        batch_size,
+        min_queue_size,
+        workers,
+        raise_errors,
+        verbose,
+        pbar,
+        allowed_fail_count,
+    )
+
+
+def get_pinger(iterable, pbar):
+    if not pbar:
+        return lambda: None
+
     from tqdm import tqdm
 
     try:
         total = len(iterable)
     except Exception:
         total = None
-
-    return tqdm(total=total).update
+    return tqdm(total=total, desc=pbar if isinstance(pbar, str) else "parallel").update
